pitchtools.PitchClassObject
===========================

.. inheritance-diagram:: abjad.tools.pitchtools.PitchClassObject.PitchClassObject.PitchClassObject
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.PitchClassObject.PitchClassObject.PitchClassObject

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.PitchClassObject.PitchClassObject.PitchClassObject.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.PitchClassObject.PitchClassObject.PitchClassObject.__eq__

    Inherited from :py:class:`abctools.AttributeEqualityAbjadObject <abjad.tools.abctools.AttributeEqualityAbjadObject.AttributeEqualityAbjadObject.AttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.pitchtools.PitchClassObject.PitchClassObject.PitchClassObject.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.PitchClassObject.PitchClassObject.PitchClassObject.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.PitchClassObject.PitchClassObject.PitchClassObject.__hash__

.. automethod:: abjad.tools.pitchtools.PitchClassObject.PitchClassObject.PitchClassObject.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.PitchClassObject.PitchClassObject.PitchClassObject.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.PitchClassObject.PitchClassObject.PitchClassObject.__ne__

    Inherited from :py:class:`abctools.AttributeEqualityAbjadObject <abjad.tools.abctools.AttributeEqualityAbjadObject.AttributeEqualityAbjadObject.AttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.pitchtools.PitchClassObject.PitchClassObject.PitchClassObject.__repr__

    Inherited from :py:class:`abctools.AttributeEqualityAbjadObject <abjad.tools.abctools.AttributeEqualityAbjadObject.AttributeEqualityAbjadObject.AttributeEqualityAbjadObject>`
